@@ -77,11 +77,13 @@ def has_tag(file,tag):
     result_array = []
     file_array = _parse_file_obj_list(file)
     for file in file_array:
+        if 'iptc_data' not in file:
+            file = get_meta(file)
         if tag in file['iptc_data']['Keywords']:
             result_array.append(file)
-    if len(result_array) > 0:
-        return True
-    return False
+    if len(result_array) == 1:
+        return result_array[0]
+    return result_array
 
 
 def get_meta(file):
