@@ -1,4 +1,6 @@
 
+import colemen_string_utils as strUtils
+
 
 def get_kwarg(key_name, default_val=False, value_type=None, **kwargs):
     kwargs = keys_to_lower(kwargs)
@@ -7,7 +9,7 @@ def get_kwarg(key_name, default_val=False, value_type=None, **kwargs):
 
     for name in key_name:
         # generate basic variations of the name
-        varis = gen_variations(name)
+        varis = strUtils.gen.variations(name)
         for v_name in varis:
             if v_name in kwargs:
                 if value_type is not None:
@@ -18,18 +20,18 @@ def get_kwarg(key_name, default_val=False, value_type=None, **kwargs):
     return default_val
 
 
-def gen_variations(string):
-    string = str(string)
-    varis = []
-    lower = string.lower()
-    upper = string.upper()
-    snake_case = lower.replace(" ", "_")
-    screaming_snake_case = upper.replace(" ", "_")
-    varis.append(lower)
-    varis.append(upper)
-    varis.append(snake_case)
-    varis.append(screaming_snake_case)
-    return varis
+# def gen_variations(string):
+#     string = str(string)
+#     varis = []
+#     lower = string.lower()
+#     upper = string.upper()
+#     snake_case = lower.replace(" ", "_")
+#     screaming_snake_case = upper.replace(" ", "_")
+#     varis.append(lower)
+#     varis.append(upper)
+#     varis.append(snake_case)
+#     varis.append(screaming_snake_case)
+#     return varis
 
 
 def keys_to_lower(dictionary):
